import createAxios from '@/utils/request' 


// 密码规则修改
export function ruleUpdate(data) {
    return createAxios({
        url: '/user-boot/password/ruleUpdate',
        method: 'post',
        data
    })
}
// 获取密码规则
export function getRule(data) {
    return createAxios({
        url: '/user-boot/password/getRule',
        method: 'post',
        data
    })
}
// 解锁超级管理员
export function unlockRoot(data) {
    return createAxios({
        url: '/user-boot/password/unlockRoot',
        method: 'post',
        data
    })
}

//根据客户端名查询信息
export function getClientInfoByPath() {
   
    return createAxios({
        url: '/user-boot/authClient/getAuthClientByName/njcn',
        method: 'GET',
        headers: {
            'Content-Type': 'application/x-www-form-urlencoded'
        }
      
    })
}

//客户端会话配置更新
export function updateClientSessionConfig(data) {
    return createAxios({
        url: '/user-boot/authClient/sessionConfigUpdate',
        method: 'post',
        data
    })
}

//获取用户配置
export function getUserConfig() {
    return createAxios({
        url: '/user-boot/password/getUserStrategyList',
        method: 'post'
    })
}

//查询系统列表
export function getSystemList() {
    return createAxios({
      url: '/system-boot/config/getSysConfigData',
      method: 'get'
    })
}

//激活系统配置
export function activeSystemConfig(data) {
    return createAxios({
        url: '/system-boot/config/updateSysConfig',
        method: 'post',
        data
    })
}

//删除系统配置
export function deleteSystemConfig( data) {
    return createAxios({
            url: '/system-boot/config/removeSysConfigById',
            method: 'get',
            params: data
    })
}

//新增系统配置
export function addSystemConfig(data) {
    return createAxios({
        url: '/system-boot/config/addSysConfig',
        method: 'post',
        data
    })
}

//修改系统配置
export function updateSystemConfig(data) {
    return createAxios({
        url: '/system-boot/config/updateSysConfig',
        method: 'post',
        data
    })
}